@@ -10,39 +10,39 @@ and use `{{ "now"|timestamp }}` to output timestamps for RSS feeds and such.
 The default date format is outputs something like "11 May 2011".  Here are, for
 my own reference, other formatters::
 
-    # as of datetime.datetime(2012, 4, 11, 22, 40, 50, 362334)
-    %a:  Locale's abbreviated weekday name.                     "Fri"
-    %A:  Locale's full weekday name.                            "Friday"
+    # as of datetime.datetime(2011, 4, 7, 9, 1, 2, 362334)
+    %a:  Locale's abbreviated weekday name.                     "Thu"
+    %A:  Locale's full weekday name.                            "Thursday"
     %b:  Locale's abbreviated month name.                       "Apr"
     %B:  Locale's full month name.                              "April"
-    %c:  Locale's appropriate date and time representation.     "Fri April 11 22:40:50 2012"
-    %C:  ???                                                    "20"
-    %d:  Day of the month as a decimal number [01,31].          "11"
-    %D:  ???                                                    "04/11/12"
-    %e:  ???                                                    "11"
-    %f:  ???                                                    "362334"
-    %F:  ???                                                    "2012-04-11"
-    %g:  ???                                                    "12"
-    %G:  ???                                                    "2012"
+    %c:  Locale's appropriate date and time representation.     "Thu April  7 09:01:02 2012"
+    %C:  ??? (century?)                                         "20"
+    %d:  Day of the month as a decimal number [01,31].          "07"
+    %D:  ???                                                    "04/07/12"
+    %e:  Day of the month without "0" in front                  " 7"
+    %f:  ???                                                    "000003"
+    %F:  ???                                                    "2012-04-07"
+    %g:  ???                                                    "11"
+    %G:  ???                                                    "2011"
     %h:  ???                                                    "Apr"
-    %H:  Hour (24-hour clock) as a decimal number [00,23].      "22"
-    %I:  Hour (12-hour clock) as a decimal number [01,12].      "10"
-    %j:  Day of the year as a decimal number [001,366]          "102"
-    %k:  ???                                                    "22"
-    %l:  ???                                                    "10"
+    %H:  Hour (24-hour clock) as a decimal number [00,23].      "09"
+    %I:  Hour (12-hour clock) as a decimal number [01,12].      "09"
+    %j:  Day of the year as a decimal number [001,366]          "097"
+    %k:  ???                                                    " 9"
+    %l:  ???                                                    " 9"
     %m:  Month as a decimal number [01,12].                     "04"
-    %M:  Minute as a decimal number [00,59].                    "40"
-    %n:  ???                                                    "\n"
-    %p:  Locale's equivalent of either AM or PM.                "PM"
-    %r:  ???                                                    "10:40:50 PM"
-    %R:  ???                                                    "22:40"
-    %s:  unix timestamp                                         "1334205650"
-    %S:  Second as a decimal number [00,61].                    "50"
-    %T:  22:40:50
-    %x:  Locale's appropriate date representation.              "04/11/12"
-    %X:  Locale's appropriate time representation.              "22:40:50"
-    %y:  Year without century as a decimal number [00,99].      "12"
-    %Y:  Year with century as a decimal number.                 "2012"
+    %M:  Minute as a decimal number [00,59].                    "01"
+    %n:  newline                                                "\n"
+    %p:  Locale's equivalent of either AM or PM.                "AM"
+    %r:  time with seconds and am/pm                            "09:01:02 AM"
+    %R:  military time in HH:MM in 24-h                         "09:01"
+    %s:  unix timestamp                                         "1302188462"
+    %S:  Second as a decimal number [00,61].                    "02"
+    %T:  Military time, with seconds                            "09:01:02"
+    %x:  Locale's appropriate date representation.              "04/07/12"
+    %X:  Locale's appropriate time representation.              "09:01:02"
+    %y:  Year without century as a decimal number [00,99].      "11"
+    %Y:  Year with century as a decimal number.                 "2011"
     %Z:  Time zone name (no characters if no time zone exists). ""
     %%:  A literal '%' character.                               "%"
 
@@ -84,7 +84,7 @@ def to_datetime(value):
 
 def date(value, format='%d %b %Y'):
     """
-    Default format: 13 May 2012
+    Default format: 01 May 2012
     """
     if not value:
         return ''
